# Contributor License Agreement

Thank you for your interest in contributing to HEBBS Python SDK ("the Project"). To clarify the intellectual property rights granted with contributions from any person or entity, Parag Arora ("the Copyright Holder") requires a Contributor License Agreement (CLA) on file from each contributor. This agreement is for your protection as a contributor as well as for the protection of the Copyright Holder and the Project's users.

By submitting a pull request, issue, or any other contribution to this repository, you agree to the following terms:

## 1. Definitions

**"You"** (or **"Your"**) shall mean the copyright owner or legal entity authorized by the copyright owner that is making this Agreement. For legal entities, the entity making a Contribution and all other entities that control, are controlled by, or are under common control with that entity are considered to be a single Contributor.

**"Contribution"** shall mean any original work of authorship, including any modifications or additions to an existing work, that is intentionally submitted by You to this Project for inclusion in, or documentation of, the Project. For the purposes of this definition, "submitted" means any form of electronic, verbal, or written communication sent to the Project, including but not limited to pull requests, issues, comments, and patches.

## 2. Grant of Copyright License

Subject to the terms and conditions of this Agreement, You hereby grant to Parag Arora and to recipients of software distributed by the Project a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare derivative works of, publicly display, publicly perform, sublicense, and distribute Your Contributions and such derivative works.

## 3. Grant of Patent License

Subject to the terms and conditions of this Agreement, You hereby grant to Parag Arora and to recipients of software distributed by the Project a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by You that are necessarily infringed by Your Contribution(s) alone or by combination of Your Contribution(s) with the Work to which such Contribution(s) was submitted.

## 4. Representations

You represent that:

- Each of Your Contributions is Your original creation.
- You have the legal authority to enter into this Agreement.
- Your Contribution does not violate any third party's intellectual property rights.
- If Your employer(s) has rights to intellectual property that You create, You have received permission to make Contributions on behalf of that employer, or Your employer has waived such rights for Your Contributions to this Project.

## 5. No Obligation

You understand that the decision to include Your Contribution in the Project is entirely at the discretion of the Copyright Holder, and this Agreement does not obligate the Copyright Holder to use or include Your Contribution.

## 6. Support

You are not expected to provide support for Your Contributions, except to the extent You desire to provide support. You may provide support for free, for a fee, or not at all.

## 7. Disclaimer

Unless required by applicable law or agreed to in writing, You provide Your Contributions on an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE.

---

**How to sign:** By submitting a pull request to this repository, you acknowledge that you have read and agree to the terms of this Contributor License Agreement.

**Copyright Holder:** Parag Arora
**Project:** HEBBS Python SDK
**Effective Date:** March 6, 2025
